@@ -39,16 +39,30 @@ class Standup::Diary::Template :does( Date ) :does( Project ) {
 
 =head1 NAME
 
-Standup::Diary::Template - Manage diary entry markdown template
+Standup::Diary::Template - Diary entry markdown template
 
 =head1 SYNOPSIS
 
+  my $template = Standup::Diary::Template->new(
+    date         => $self->date,
+    project_name => $self->project_name
+  ));
+
+  $template->render();
+
 =head1 DESCRIPTION
 
+Markdown template, for the daily needs.
+
 =head1 METHODS
 
 =head2 get_template()
 
+Return a un-interpreted template string respecting the
+L<Mojo::Template|https://docs.mojolicious.org/Mojo/Template> engine syntax.
+
 =head2 render()
 
+Interpolate the template with the provided data.
+
 =cut
